@@ -58,14 +58,16 @@
 #' profileSimIBD(y, simy, seed = 12)
 #'
 #' @export
-profileSimIBD = function(x, ibdpattern, ids = NULL, markers = NULL, seed = NULL, verbose = TRUE) {
+profileSimIBD = function(x, ibdpattern, ids = NULL, markers = NULL, seed = NULL, 
+                         verbose = TRUE) {
   
   # Set seed if given
   if(!is.null(seed))
     set.seed(seed)
   
   if(!is.data.frame(ibdpattern) && is.list(ibdpattern))
-    return(lapply(ibdpattern, function(patt) profileSimIBD(x, patt, ids = ids, markers = markers)))
+    return(lapply(ibdpattern, function(patt) 
+      profileSimIBD(x, patt, ids = ids, markers = markers, verbose = verbose)))
   
   if(!is.null(markers))
     x = selectMarkers(x, markers)
@@ -119,7 +121,10 @@ profileSimIBD = function(x, ibdpattern, ids = NULL, markers = NULL, seed = NULL,
     
     # IBD pattern for this marker
     achr = aChr[[mchr[i]]]
-    rw = if(nrow(achr) > 1) findInterval(mpos[i], achr[, 'startMB'], all.inside = TRUE) else 1L
+    nr = nrow(achr)
+    
+    interv = c(achr[, 'startMB'], achr[nr, 'endMB'])
+    rw = if(nr > 1) findInterval(mpos[i], interv, all.inside = TRUE) else 1L
     ibdpat = achr[rw, patcols]
     ibdmat = achr[rw, matcols]
     
