@@ -1,4 +1,7 @@
 suppressMessages(suppressPackageStartupMessages({
+  library(shiny)
+  library(shinyjs)
+  library(shinyWidgets)
   library(pedtools)
   library(ribd)
   library(ibdsim2)
@@ -7,8 +10,6 @@ suppressMessages(suppressPackageStartupMessages({
   library(patchwork)
   library(glue)
   library(zip)
-  library(shiny)
-  library(shinyjs)
 }))
 
 
@@ -98,6 +99,10 @@ fluidRow(
       column(6, align = "center", plotOutput("pedplot2", height = "295px"))
     ),
     plotOutput("ibdplot", width = "100%"),
+    absolutePanel(id = "origin0panel",
+      bottom = 0, left = 0, width = "auto", draggable = FALSE, style = "z-index:1000",
+      prettySwitch("orig0", label = "Origin", value = FALSE, slim = TRUE, status = "default")
+    )
   ),
   
   # Right sidebar
@@ -143,7 +148,7 @@ fluidRow(
     fluidRow(
       column(4, 
         h4("Settings"),
-        numericInput("nsims", "Sims", value = 500, min = 1, max = 10000),
+        numericInput("nsims", "Number of sims", value = 500, min = 5, max = 5000),
       ),
       column(8, 
         radioButtons("unit", "Length unit", selected = "cm", inline = TRUE, 
@@ -159,7 +164,7 @@ fluidRow(
           column(6, numericInput("obs-total", "Total length", value = "")),
           column(6, numericInput("obs-nseg", "Count", value = "")),
       )),
-      column(4, textAreaInput("obs-segs", "Segments", value = "", rows = 2)),
+      column(4, textAreaInput("obs-segs", "Segments", value = "", rows = 4)),
     ))),
   ),
 
@@ -241,7 +246,9 @@ server = function(input, output, session) {
     loadMap("decode19", chrom = chr, uniform = unif, sexAverage = !sexspec)
   })
   
-
+  maplen1 = reactive(getMapLength(map1(), input$unit, input$chrom1))
+  maplen2 = reactive(getMapLength(map2(), input$unit, input$chrom2))
+  
 # Simulations -------------------------------------------------------------
 
   sim1 = reactiveVal(NULL)
@@ -257,7 +264,7 @@ server = function(input, output, session) {
   
   # Simulate!
   observeEvent(input$simulate1, {
-    chk = checkSimInput(ped1(), ids1(), input$analysis)
+    chk = checkSimInput(ped1(), ids1(), input$analysis, input$nsims)
     if(chk != "ok")
       return(errModal(chk))
     disable("simulate1")
@@ -267,7 +274,7 @@ server = function(input, output, session) {
   })
   
   observeEvent(input$simulate2, {
-    chk = checkSimInput(ped2(), ids2(), input$analysis)
+    chk = checkSimInput(ped2(), ids2(), input$analysis, input$nsims)
     if(chk != "ok")
       return(errModal(chk))
     disable("simulate2")
@@ -367,8 +374,13 @@ server = function(input, output, session) {
     
     req(!isnull)  # return if both empty
     
+    # Map length (for percentages)
+    if(!any(skip)) maplen = if(maplen1() == maplen2()) maplen1() else NULL
+    else maplen = if(skip[1]) maplen2() else maplen1()
+    
     g = generateIbdPlot(segData[!skip], input$analysis, cols = cols[!skip],
-                        unit = input$unit, observed = observed())
+                        unit = input$unit, observed = observed(), 
+                        orig0 = input$orig0, maplen = maplen)
     suppressWarnings(print(g))
   })
   
